<p align="center"><img src="https://github.com/packing-box/python-malsearch/raw/main/docs/pages/img/logo.png"></p>
<h1 align="center">MalSearch <a href="https://twitter.com/intent/tweet?text=MalSearch%20-%20Search%20for%20samples%20from%20various%20malware%20databases.%0D%0APython%20library%20for%20getting%20samples%20from%20multiple%20malware databases.%0D%0Ahttps%3a%2f%2fgithub%2ecom%2fpacking-box%2fpython-malsearch%0D%0A&hashtags=python,programming,malware"><img src="https://img.shields.io/badge/Tweet--lightgrey?logo=twitter&style=social" alt="Tweet" height="20"/></a></h1>
<h3 align="center">Search for samples from various malware databases.</h3>

[![PyPi](https://img.shields.io/pypi/v/malsearch.svg)](https://pypi.python.org/pypi/malsearch/)
[![Read The Docs](https://readthedocs.org/projects/python-malsearch/badge/?version=latest)](https://python-malsearch.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://github.com/packing-box/python-malsearch/actions/workflows/python-package.yml/badge.svg)](https://github.com/packing-box/python-malsearch/actions/workflows/python-package.yml)
[![Coverage Status](https://raw.githubusercontent.com/packing-box/python-malsearch/main/docs/coverage.svg)](#)
[![Python Versions](https://img.shields.io/pypi/pyversions/malsearch.svg)](https://pypi.python.org/pypi/malsearch/)
[![Known Vulnerabilities](https://snyk.io/test/github/packing-box/python-malsearch/badge.svg?targetFile=requirements.txt)](https://snyk.io/test/github/packing-box/python-malsearch?targetFile=requirements.txt)
[![License](https://img.shields.io/pypi/l/malsearch.svg)](https://pypi.python.org/pypi/malsearch/)

This library communicates with API's of the following malware databases to collect malware samples:

- [Malpedia](https://malpedia.caad.fkie.fraunhofer.de/usage/api)
- [MalShare](https://malshare.com/doc.php)
- [Malware Bazaar](https://bazaar.abuse.ch/api)
- [Triage](https://tria.ge/docs)
- [VirusShare](https://virusshare.com/apiv2_reference)
- [VirusTotal](https://docs.virustotal.com/reference/overview)

This library also communicates with API's or websites of the following repositories to get sample hash feeds:

- [Maldatabase](https://maldatabase.com/api-doc.html)


```sh
pip install malsearch
```

## Usage

TODO


